@@ -436,7 +436,7 @@ void KompareListView::mousePressEvent(QMouseEvent* e)
     QPoint vp = e->pos();
     KompareListViewDiffItem* diffItem = diffItemAt(vp);
     if (diffItem && diffItem->difference()->type() != Difference::Unchanged) {
-        emit differenceClicked(diffItem->difference());
+        Q_EMIT differenceClicked(diffItem->difference());
     }
 }
 
@@ -446,8 +446,8 @@ void KompareListView::mouseDoubleClickEvent(QMouseEvent* e)
     KompareListViewDiffItem* diffItem = diffItemAt(vp);
     if (diffItem && diffItem->difference()->type() != Difference::Unchanged) {
         // FIXME: make a new signal that does both
-        emit differenceClicked(diffItem->difference());
-        emit applyDifference(!diffItem->difference()->applied());
+        Q_EMIT differenceClicked(diffItem->difference());
+        Q_EMIT applyDifference(!diffItem->difference()->applied());
     }
 }
 
@@ -507,7 +507,7 @@ void KompareListView::wheelEvent(QWheelEvent* e)
 void KompareListView::resizeEvent(QResizeEvent* e)
 {
     QTreeWidget::resizeEvent(e);
-    emit resized();
+    Q_EMIT resized();
 }
 
 KompareListViewItemDelegate::KompareListViewItemDelegate(QObject* parent)
@@ -855,11 +855,7 @@ void KompareListViewLineItem::paintText(QPainter* p, const QColor& bg, int colum
 //                     p->setPen( Qt::black );
                     brush = normalBrush;
                 }
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
                 chunkWidth = p->fontMetrics().horizontalAdvance(textChunk);
-#else
-                chunkWidth = p->fontMetrics().width(textChunk);
-#endif
                 p->fillRect(offset, 0, chunkWidth, paintHeight(), brush);
                 p->drawText(offset, 0,
                             chunkWidth, paintHeight(),
@@ -876,11 +872,7 @@ void KompareListViewLineItem::paintText(QPainter* p, const QColor& bg, int colum
             QFont font(p->font());
             font.setBold(false);
             p->setFont(font);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
             chunkWidth = p->fontMetrics().horizontalAdvance(textChunk);
-#else
-            chunkWidth = p->fontMetrics().width(textChunk);
-#endif
             p->fillRect(offset, 0, chunkWidth, paintHeight(), normalBrush);
             p->drawText(offset, 0,
                         chunkWidth, paintHeight(),
