@@ -37,6 +37,7 @@
 
 #include "kompareinterface.h"
 
+#include "kompare_version.h"
 #include "kompare_shell.h"
 #include "kompareurldialog.h"
 
@@ -49,10 +50,13 @@
  */
 int main(int argc, char* argv[])
 {
+    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("kompare");
 
-    KAboutData aboutData(QStringLiteral("kompare"),  i18n("Kompare"), QStringLiteral("4.1.3"),
+    KAboutData aboutData(QStringLiteral("kompare"),  i18n("Kompare"),
+                         QStringLiteral(KOMPARE_VERSION_STRING),
                          i18n("A program to view the differences between files and optionally generate a diff"),
                          KAboutLicense::GPL,
                          i18n("(c) 2001-2004 John Firebaugh, (c) 2001-2005,2009 Otto Bruggeman, (c) 2004-2005 Jeff Snyder, (c) 2007-2012 Kevin Kofler"));
@@ -67,8 +71,6 @@ int main(int argc, char* argv[])
     KAboutData::setApplicationData(aboutData);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kompare"), app.windowIcon()));
 
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
     parser.addOption(QCommandLineOption(QStringLiteral("c"), i18n("This will compare URL1 with URL2")));
